/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EJB3.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.struct;

import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IAssemblyDescriptor;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IEJB3;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IEnterpriseBeans;
import org.ow2.util.ee.metadata.ejbjar.api.xml.struct.IInterceptors;

/**
 * This class represents an EJB-Jar deployment descriptor.
 * @author Florent Benoit
 */
public class EJB3 implements IEJB3 {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 3046313759582470535L;

    /**
     * Enterprise-beans element.
     */
    private IEnterpriseBeans enterpriseBeans = null;

    /**
     * interceptors element.
     */
    private IInterceptors interceptors = null;

    /**
     * assembly-descriptor element.
     */
    private IAssemblyDescriptor assemblyDescriptor = null;

    /**
     * metadataComplete.
     */
    private boolean metadataComplete;

    /**
     * Gets the enterprise-beans element.
     * @return the enterprise-beans
     */
    public IEnterpriseBeans getEnterpriseBeans() {
        return enterpriseBeans;
    }

    /**
     * Sets the enterprise-beans element.
     * @param enterpriseBeans the element to set.
     */
    public void setEnterpriseBeans(final IEnterpriseBeans enterpriseBeans) {
        this.enterpriseBeans = enterpriseBeans;
    }

    /**
     * Gets the interceptors element.
     * @return the interceptors
     */
    public IInterceptors getInterceptors() {
        return interceptors;
    }

    /**
     * Sets the interceptors element.
     * @param interceptors the element to set.
     */
    public void setInterceptors(final IInterceptors interceptors) {
        this.interceptors = interceptors;
    }

    /**
     * Gets the assembly-descriptor element.
     * @return the assembly-descriptor
     */
    public IAssemblyDescriptor getAssemblyDescriptor() {
        return assemblyDescriptor;
    }

    /**
     * Sets the assembly-descriptor element.
     * @param assemblyDescriptor the element to set.
     */
    public void setAssemblyDescriptor(final IAssemblyDescriptor assemblyDescriptor) {
        this.assemblyDescriptor = assemblyDescriptor;
    }

    /**
     * Set metadataComplete.
     * @param metadataComplete true if deployment descriptor contains all information
     */
    public void setMetadataComplete(final boolean metadataComplete) {
        this.metadataComplete = metadataComplete;
    }

    /**
     * Get metadataComplete.
     * @return true if deployment descriptor contains all information
     */
    public boolean isMetadataComplete() {
        return metadataComplete;
    }

}
